@@ -10,15 +10,9 @@
 
 #include "kontactkcmultidialog_p.h"
 #include "kontactsettingsdialog.h"
-#include <KCModuleInfo>
 
-#include <QHash>
-#include <QSet>
 #include <QString>
 
-#include <KPageWidgetModel>
-#include <KService>
-
 class KontactSettingsDialogPrivate : public KontactKCMultiDialogPrivate
 {
     friend class PageNode;
