@@ -31,7 +31,7 @@ using namespace Kontact;
 
 #include <iostream>
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 #endif
 using namespace std;
 
@@ -178,7 +178,6 @@ int main(int argc, char **argv)
     about.addAuthor(i18n("Zack Rusin"), QString(), QStringLiteral("zack@kde.org"));
     about.addAuthor(i18n("Matthias Hoelzer-Kluepfel"), i18n("Original Author"), QStringLiteral("mhk@kde.org"));
     about.addCredit(i18n("Torgny Nyblom"), i18n("Git Migration"), QStringLiteral("nyblom@kde.org"));
-    about.setOrganizationDomain("kde.org");
     app.setAboutData(about);
     app.setWindowIcon(QIcon::fromTheme(QStringLiteral("kontact")));
     app.setDesktopFileName(QStringLiteral("org.kde.kontact"));
